[![PyPI version](https://badge.fury.io/py/calibr8.svg)](https://badge.fury.io/py/calibr8)
[![pipeline](https://github.com/michaelosthege/calibr8/workflows/pipeline/badge.svg)](https://github.com/michaelosthege/calibr8/actions)
[![coverage](https://codecov.io/gh/michaelosthege/calibr8/branch/master/graph/badge.svg)](https://codecov.io/gh/michaelosthege/calibr8)


# `calibr8`
This package provides templates and functions for performing likelihood-based error modeling.
To see implementation examples & excercises, you can go to [notebooks/](notebooks).

# Installation
`calibr8` is released on [PyPI](https://pypi.org/project/calibr8/):
```
pip install calibr8
```
# Usage and Citing
`calibr8` is licensed under the [GNU Affero General Public License v3.0](https://github.com/michaelosthege/calibr8/blob/master/LICENSE).
